==> haskell-charset-0.3.7.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-charset/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-2fd42617bb9676e0894dac84260c33bd
key: chars_FpKsxFlqG172ee7zUSiBjs
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.Common Data.CharSet.Posix
    Data.CharSet.Posix.Ascii Data.CharSet.Posix.Unicode
    Data.CharSet.Unicode Data.CharSet.Unicode.Block
    Data.CharSet.Unicode.Category Data.CharSet.ByteSet
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/charset-0.3.7.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-FpKsxFlqG172ee7zUSiBjs
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    semigroups-0.18.0.1-09717ed0a84e1dbeffebbb54d604d271
    unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.7.1-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-charset/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-07fa1295548c21364abbf3188fa2df38
key: chars_68hDqbOXOtH3ywWm3VlaWR
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.Common Data.CharSet.Posix
    Data.CharSet.Posix.Ascii Data.CharSet.Posix.Unicode
    Data.CharSet.Unicode Data.CharSet.Unicode.Block
    Data.CharSet.Unicode.Category Data.CharSet.ByteSet
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/charset-0.3.7.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-68hDqbOXOtH3ywWm3VlaWR
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
